# VeMonitor_m8

![CI/CD](https://github.com/vemonitor/vemonitor_m8/actions/workflows/python-package.yml/badge.svg?branch=main)
[![PyPI package](https://img.shields.io/pypi/v/vemonitor_m8.svg)](https://pypi.org/project/vemonitor_m8/)
[![Known Vulnerabilities](https://snyk.io/test/github/mano8/vemonitor_m8/badge.svg)](https://snyk.io/test/github/mano8/vemonitor_m8)
[![codecov](https://codecov.io/gh/vemonitor/vemonitor_m8/graph/badge.svg?token=M7VgGzkApi)](https://codecov.io/gh/vemonitor/vemonitor_m8)
[![Codacy Badge](https://app.codacy.com/project/badge/Grade/c401bed6812d4f9bb77bfaee16cf0abe)](https://www.codacy.com/gh/mano8/vemonitor_m8/dashboard?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=mano8/vemonitor_m8&amp;utm_campaign=Badge_Grade)
[![Downloads](https://static.pepy.tech/badge/vemonitor_m8)](https://pepy.tech/project/vemonitor_m8)

Victron Serial VeDirect Monitoring App
